## dbt-tests-adapter 1.17.0 - July 29, 2025

### Features

- Add test for scenario where soure/target relations are the same ([#1198](https://github.com/dbt-labs/dbt-adapters/issues/1198))
- Add BaseSnapshotEphemeralHardDeletes test  ([#1201](https://github.com/dbt-labs/dbt-adapters/issues/1201))

### Fixes

- Fix test suite simple_snapshot/test_various_configs import path ([#972](https://github.com/dbt-labs/dbt-adapters/issues/972))

### Under the Hood

- Improve test coverage for snapshots with new record mode ([#654](https://github.com/dbt-labs/dbt-adapters/issues/654))

### Contributors
- [@99Lys](https://github.com/99Lys) ([#972](https://github.com/dbt-labs/dbt-adapters/issues/972))
- [@lpillmann](https://github.com/lpillmann) ([#654](https://github.com/dbt-labs/dbt-adapters/issues/654))
